//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//						(c) 1997 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	clex.cc --- Command-Line-EXpression-evaluator
//
//	DESCRIPTION:
//		A calculator which receives a boolean or arithmetic expression
//		as an argument, evaluates it and prints the result on standard
//		output. If a valid arithmetic expression is given, the numeric result
//		is printed on stdout and the program exits with 0. If an logic
//		expression is given, clex is mute and conveys the result of
//		the evaluation to the caller via the return value:
//		0/1: expression evaluates to true/false
//
//	CHANGE HISTORY:
//		UL, 1998-05-26: 1.0.0: - initial version
//		UL, 1998-10-06: 1.1.0: - #include <iomanip> added
//
//	AUTHOR:
//		U. Lammers, Tue May 26 17:37:41 MET DST 1998
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /data/xmm12/cvsadmin/soc_repos/task_devel/packages/tools/src/clex/clex.cc,v 1.5 2001/04/02 12:37:29 ulammers Exp $
//

#include <iostream>
#include <iomanip>
#include "errstr.h"
#include "Evaluator.h"

int main(int argc, char *argv[])
{
	if (argc != 2)
		errstr<<"Usage: "<<argv[0]<<" <expr>\n"<<Sas::fatal(argv[0]);

	Evaluator evaluator(argv[1]);	//	construct evaluator

	//	check if we have identifiers
	NumericSymbols idents = evaluator.numericIdentifiers();
	for (unsigned n=0; n<idents.name.size(); ++n)
		cin>>*idents.valuePtr[n];

	//	check if row number was specified
	if (evaluator.rowNumber())
		cin>>*evaluator.rowNumber();

	//	evaluate
	int res = 0;
	if (evaluator.isLogic())
		//	boolean expression given
		res = evaluator.evalLogic() ? 0 : 1;
	else
		//	arithmetic expression given
		cout<<setprecision(15)<<evaluator.evalArith()<<endl;

	return res;
} // main()
